diff --git a/src/Fl_Gl_Choice.cxx b/src/Fl_Gl_Choice.cxx
index 7af8039..c8812ae 100644
--- a/src/Fl_Gl_Choice.cxx
+++ b/src/Fl_Gl_Choice.cxx
@@ -127,6 +127,13 @@ void Fl_Cocoa_Gl_Window_Driver::delete_gl_context(GLContext context) {
 #include "drivers/WinAPI/Fl_WinAPI_Window_Driver.H"
 extern void fl_save_dc(HWND, HDC);
 
+// STR #3191: select pixel format with composition support
+// Ref: PixelFormatDescriptor Object
+// https://msdn.microsoft.com/en-us/library/cc231189.aspx
+#if !defined(PFD_SUPPORT_COMPOSITION)
+# define PFD_SUPPORT_COMPOSITION (0x8000)
+#endif
+
 Fl_Gl_Choice *Fl_WinAPI_Gl_Window_Driver::find(int m, const int *alistp)
 {
   Fl_Gl_Choice *g = Fl_Gl_Window_Driver::find_begin(m, alistp);
@@ -149,13 +156,24 @@ Fl_Gl_Choice *Fl_WinAPI_Gl_Window_Driver::find(int m, const int *alistp)
     if ((!(m & FL_STEREO)) != (!(pfd.dwFlags & PFD_STEREO))) continue;
     if ((m & FL_DEPTH) && !pfd.cDepthBits) continue;
     if ((m & FL_STENCIL) && !pfd.cStencilBits) continue;
+    printf("pfd #%d supports composition: %s\n", i, (pfd.dwFlags & PFD_SUPPORT_COMPOSITION) ? "yes" : "no");
+    printf("    ... & PFD_GENERIC_FORMAT: %s\n", (pfd.dwFlags & PFD_GENERIC_FORMAT) ? "generic" : "accelerated");
+    printf("    ... Overlay Planes      : %d\n", pfd.bReserved & 15);
+    printf("    ... Color & Depth       : %d, %d\n", pfd.cColorBits, pfd.cDepthBits);
+    if (pixelformat)
+      printf("        current pixelformat : %d\n", pixelformat);
+    fflush(stdout);
+
     // see if better than the one we have already:
     if (pixelformat) {
-      // offering non-generic rendering is better (read: hardware accelleration)
+      // offering non-generic rendering is better (read: hardware acceleration)
       if (!(chosen_pfd.dwFlags & PFD_GENERIC_FORMAT) &&
           (pfd.dwFlags & PFD_GENERIC_FORMAT)) continue;
       // offering overlay is better:
       else if (!(chosen_pfd.bReserved & 15) && (pfd.bReserved & 15)) {}
+      // otherwise prefer a format that supports composition (STR #3119)
+      else if ((chosen_pfd.dwFlags & PFD_SUPPORT_COMPOSITION) &&
+	       !(pfd.dwFlags & PFD_SUPPORT_COMPOSITION)) continue;
       // otherwise more bit planes is better:
       else if (chosen_pfd.cColorBits > pfd.cColorBits) continue;
       else if (chosen_pfd.cDepthBits > pfd.cDepthBits) continue;
@@ -163,7 +181,14 @@ Fl_Gl_Choice *Fl_WinAPI_Gl_Window_Driver::find(int m, const int *alistp)
     pixelformat = i;
     chosen_pfd = pfd;
   }
-  //printf("Chosen pixel format is %d\n", pixelformat);
+  static int bb = 0;
+  if (!bb) {
+    bb = 1;
+    printf("PFD_SUPPORT_COMPOSITION = 0x%x\n", PFD_SUPPORT_COMPOSITION);
+  }
+  printf("Chosen pixel format is %d\n", pixelformat);
+  printf("Pixel format supports composition: %s\n", (chosen_pfd.dwFlags & PFD_SUPPORT_COMPOSITION) ? "yes" : "no");
+  fflush(stdout);
   if (!pixelformat) return 0;
   
   g = new Fl_Gl_Choice(m, alistp, first);
